@@ -4,7 +4,7 @@ from .actions import (
     get_simple_temp,
     get_now_temp,
     easy_ocr,
-    easy_translate,
+    simple_translate,
     meme_gen,
     web_screenshot,
     create_folder,
