@@ -32,7 +32,7 @@ class get_now_temp(Action):
     # Should add something like this
     # procs = [weather.get_weather, _p(weather.ret_weather,{'ascii_graphs':True})]
     # procs = [weather.get_weather, _p(weather.ret_weather,ascii_graphs=True)]
-    # The idea here is turn ascii_graphs=True into ascii_graphs=True
+    # The idea here is turn {"ascii_graphs":True} into self.ascii_graphs=True
 
 
 @dataclass
@@ -45,14 +45,14 @@ class get_simple_temp(Action):
 @dataclass
 class translate(Action):
     q: str
-    full: bool = False
+    full: bool = True
     procs = [youdao.translate_post, youdao.translate_filter]
 
 
 @dataclass
-class easy_translate(Action):
+class simple_translate(Action):
     q: str
-    procs = [youdao.easy_translate]
+    procs = [youdao.simple_translate]
 
 
 @dataclass
