@@ -31,10 +31,13 @@ class Action:
         elif isinstance(self.procs, list):
             self.procs = ProcManager(*self.procs)
 
-        seed = copy.deepcopy(self.__dict__)
+        # seed = copy.deepcopy(self.__dict__)
+        seed = self.__dict__.copy()
         seed = drop(seed, ["procs", "self"])
+        # Wait... there is no self in self.__dict__
+        # Seems like self should be when @action decorated a method
         # little dangerous here drop self only use key-name,
-        # think about if I use 'this' instead of 'self' wow...
+        # think about it, if I use 'this' instead of 'self' wow...
         ret = self.procs.excute(seed)
         # ret = self.procs(seed)
         # ret = self.procs(self.__dict__)
@@ -91,8 +94,6 @@ class action(Action):
         # TODO really need a smarter way to detect self, and get result from procs
         @wraps(decorated)
         def instead(*args, **kwd):
-            # print("Inside decotrator")
-            # print(args, kwd)
             seed = decorated(*args, **kwd)  # when decorate a method, self in args...
             self.__dict__.update(seed)
             return self
