@@ -14,11 +14,6 @@ from dao import YouDao as YouDaoClient
 TRANS_URL = "https://ke.study.163.com/code/textTrans"
 OCR_URL = "https://ke.study.163.com/code/ocrTrans"
 
-# os.environ[
-#     "token"
-# ] = "tYwB%2FcQm2vlyCP1oP%2FRujcnfAMlAJ9ET8JZgyPzHchScEvbrs%2BuXh5XOk78v%2FGS91eloNmbyH3TmBKqtY6EyhqFW%2F%2FKZPfjA4clnffrfjFU%3D"
-
-
 class ReqBuilder:
     @property
     def use_sdk(self):
@@ -155,9 +150,9 @@ def easy_ocr(path: str):
     return p(dict(path=path))
 
 
-def easy_translate(q):
+def simple_translate(q):
     # no no no , what i want is not in the 'basic'
-    return translate(q, full=True)
+    return translate(q, full=False)
 
 
 # SIGH -> I used to struggle here, until that I found it's XJ's problem
